@@ -3,7 +3,10 @@ from typing import Any, Dict
 
 
 def to_unix(text: str) -> str:
-    return text.replace("\r\n", "\n")
+    text = text.replace("\r\n", "\n")
+    if text and not text.endswith("\n"):
+        text += "\n"
+    return text
 
 
 def format_json(value: Dict[Any, Any]) -> str:
